@@ -461,26 +461,6 @@ terminal_screen_style_updated (GtkWidget *widget)
   terminal_screen_update_style (screen);
 }
 
-#ifdef ENABLE_DEBUG
-static void
-size_request (GtkWidget *widget,
-              GtkRequisition *req)
-{
-  _terminal_debug_print (TERMINAL_DEBUG_GEOMETRY,
-                         "[screen %p] size-request %d : %d\n",
-                         widget, req->width, req->height);
-}
-
-static void
-size_allocate (GtkWidget *widget,
-               GtkAllocation *allocation)
-{
-  _terminal_debug_print (TERMINAL_DEBUG_GEOMETRY,
-                         "[screen %p] size-alloc   %d : %d at (%d, %d)\n",
-                         widget, allocation->width, allocation->height, allocation->x, allocation->y);
-}
-#endif
-
 static void
 terminal_screen_init (TerminalScreen *screen)
 {
@@ -551,13 +531,6 @@ terminal_screen_init (TerminalScreen *screen)
   g_signal_connect (terminal_app_get_desktop_interface_settings (app), "changed::" MONOSPACE_FONT_KEY_NAME,
                     G_CALLBACK (terminal_screen_system_font_changed_cb), screen);
 
-#ifdef ENABLE_DEBUG
-  _TERMINAL_DEBUG_IF (TERMINAL_DEBUG_GEOMETRY)
-    {
-      g_signal_connect_after (screen, "size-request", G_CALLBACK (size_request), nullptr);
-      g_signal_connect_after (screen, "size-allocate", G_CALLBACK (size_allocate), nullptr);
-    }
-#endif
 }
 
 static void
